==========
BYONDTools
==========

A set of tools for BYOND-based games.

Overview
--------

This is a toolkit for developers of BYOND-based games intended to do common, complex
tasks that the engine itself does not currently possess.  It also exposes common
interfaces for developers wishing to obtain information from the BYOND object tree,
maps, and DMIs.

Requirements
------------

* Python 3 
* Pillow (fork of PIL)
* numpy

Use
---

The previous documentation is taking shape at http://ss13.pomf.se/wiki/index.php/User:N3X15/Guide_to_BYONDTools
This may be out of step with the newest version.

API Status
----------

+---------------+--------+
| API Component | State  |
+---------------+--------+
| DMI           | Stable |
+---------------+--------+
| Maps          | BROKEN |
+---------------+--------+
| Object Tree   | Stable |
+---------------+--------+
| Scripting     | WIP    |
+---------------+--------+

Support
-------

No commercial or official support is provided, but you are free to 
submit bug reports or harass Comic (ComicVG/ComicIronic) in irc.rizon.net #vgstation.
